diff --git a/.github/.release-please-manifest.json b/.github/.release-please-manifest.json
index 926af9ee..d4bbf7f7 100644
--- a/.github/.release-please-manifest.json
+++ b/.github/.release-please-manifest.json
@@ -1,3 +1,3 @@
{
- ".": "14.14.0"
+ ".": "14.15.1"
}
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 90fbb7c5..3e2be0c4 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,34 @@
# Changelog
+## [14.15.1](https://github.com/LazyVim/LazyVim/compare/v14.15.0...v14.15.1) (2025-09-15)
+
+
+### Bug Fixes
+
+* **blink:** use .get method to access presets ([#6183](https://github.com/LazyVim/LazyVim/issues/6183)) ([1a729e2](https://github.com/LazyVim/LazyVim/commit/1a729e2d4c4162501fe13224d669a654849deb36))
+* **extras.ai.copilot:** update status retrieval for lualine ([#5900](https://github.com/LazyVim/LazyVim/issues/5900)) ([55e9944](https://github.com/LazyVim/LazyVim/commit/55e9944e2b1e152b5acdc9cc015978a905fc2966))
+* **lang.python:** enable venv-selector even when telescope is not available ([#5829](https://github.com/LazyVim/LazyVim/issues/5829)) ([10e5bf5](https://github.com/LazyVim/LazyVim/commit/10e5bf5c5b5fb4da0afbb2d4d2b75595502c9690))
+* **lsp:** fixed deprecated warnings ([bed725a](https://github.com/LazyVim/LazyVim/commit/bed725a054ed3e8c8c56dce7e2100335e567cf01))
+
+## [14.15.0](https://github.com/LazyVim/LazyVim/compare/v14.14.0...v14.15.0) (2025-05-12)
+
+
+### Features
+
+* **chezmoi:** enhance fzf-lua chezmoi picker and add snacks.dasbhoard entry ([#5275](https://github.com/LazyVim/LazyVim/issues/5275)) ([759a19e](https://github.com/LazyVim/LazyVim/commit/759a19e785735eb8513b4f8d4483ec5ab1b75307))
+* **keymaps:** show lang when opening treesitter inspect ([9c59668](https://github.com/LazyVim/LazyVim/commit/9c596681f684c549e69652a5c77a68bd5ecc93e3))
+* **octo:** add support for snacks picker ([#5625](https://github.com/LazyVim/LazyVim/issues/5625)) ([16a7724](https://github.com/LazyVim/LazyVim/commit/16a772452a515790c3304b358dd66a618fda3260))
+* **snippets:** mini.snippets standalone and blink.resubscribe ([#5507](https://github.com/LazyVim/LazyVim/issues/5507)) ([f2f2aea](https://github.com/LazyVim/LazyVim/commit/f2f2aea6722b530281b476c08ec60f2d320f1c3d))
+
+
+### Bug Fixes
+
+* **blink:** make sure to use `LazyVim.config.icons.kinds` ([#5668](https://github.com/LazyVim/LazyVim/issues/5668)) ([771089f](https://github.com/LazyVim/LazyVim/commit/771089f6928512ab0f431e9db04e7dc802a5e1a5))
+* **blink:** remove unnecessary `sources` from `cmdline` ([#5620](https://github.com/LazyVim/LazyVim/issues/5620)) ([5b94baa](https://github.com/LazyVim/LazyVim/commit/5b94baa1d2e7d8ec7e9a9cab82fabd8c3655d369))
+* **copilot-chat:** switch from deprecated picker integrations ([#5707](https://github.com/LazyVim/LazyVim/issues/5707)) ([b0334fd](https://github.com/LazyVim/LazyVim/commit/b0334fd57cdb920e03afab3c1940114ad43e4fbe))
+* **mason:** rename and pin to v1 ([c20c402](https://github.com/LazyVim/LazyVim/commit/c20c4022958780617424a090eee2360d560eb939))
+* **snacks.picker:** remove redundant leader-gc keymap. Closes [#5646](https://github.com/LazyVim/LazyVim/issues/5646) ([606b964](https://github.com/LazyVim/LazyVim/commit/606b96466eeb39b1c1bb576c9b99041b64705f43))
+
## [14.14.0](https://github.com/LazyVim/LazyVim/compare/v14.13.0...v14.14.0) (2025-02-15)
diff --git a/README.md b/README.md
index 4d379504..fd6a3fe0 100644
--- a/README.md
+++ b/README.md
@@ -56,7 +56,7 @@ to tweak your config as needed, along with the convenience of a pre-configured s
## ⚡️ Requirements
-- Neovim >= **0.9.0** (needs to be built with **LuaJIT**)
+- Neovim >= **0.11.0** (needs to be built with **LuaJIT**)
- Git >= **2.19.0** (for partial clones support)
- a [Nerd Font](https://www.nerdfonts.com/) **_(optional)_**
- a **C** compiler for `nvim-treesitter`. See [here](https://github.com/nvim-treesitter/nvim-treesitter#requirements)
diff --git a/doc/LazyVim.txt b/doc/LazyVim.txt
index b5d95b12..0b861808 100644
--- a/doc/LazyVim.txt
+++ b/doc/LazyVim.txt
@@ -1,4 +1,4 @@
-*LazyVim.txt* For Neovim Last change: 2025 March 01
+*LazyVim.txt* For Neovim Last change: 2025 September 15
==============================================================================
Table of Contents *LazyVim-table-of-contents*
@@ -53,7 +53,7 @@ FEATURES *LazyVim-features*
REQUIREMENTS *LazyVim-requirements*
-- Neovim >= **0.9.0** (needs to be built with **LuaJIT**)
+- Neovim >= **0.11.0** (needs to be built with **LuaJIT**)
- Git >= **2.19.0** (for partial clones support)
- a Nerd Font **(optional)**
- a **C** compiler for `nvim-treesitter`. See here
diff --git a/lua/lazyvim/config/init.lua b/lua/lazyvim/config/init.lua
index 56f2397e..9e0903c2 100644
--- a/lua/lazyvim/config/init.lua
+++ b/lua/lazyvim/config/init.lua
@@ -3,7 +3,7 @@ _G.LazyVim = require("lazyvim.util")
---@class LazyVimConfig: LazyVimOptions
local M = {}
-M.version = "14.14.0" -- x-release-please-version
+M.version = "14.15.1" -- x-release-please-version
LazyVim.config = M
---@class LazyVimOptions
@@ -353,7 +353,7 @@ function M.get_defaults()
{ name = "telescope", extra = "editor.telescope" },
},
cmp = {
- { name = "blink.cmp", extra = "coding.blink", enabled = vim.fn.has("nvim-0.10") == 1 },
+ { name = "blink.cmp", extra = "coding.blink" },
{ name = "nvim-cmp", extra = "coding.nvim-cmp" },
},
explorer = {
diff --git a/lua/lazyvim/config/keymaps.lua b/lua/lazyvim/config/keymaps.lua
index fbc7f5d1..acaf44d9 100644
--- a/lua/lazyvim/config/keymaps.lua
+++ b/lua/lazyvim/config/keymaps.lua
@@ -209,13 +209,3 @@ map("n", "", "tabnew", { desc = "New Tab" })
map("n", "]", "tabnext", { desc = "Next Tab" })
map("n", "d", "tabclose", { desc = "Close Tab" })
map("n", "[", "tabprevious", { desc = "Previous Tab" })
-
--- native snippets. only needed on < 0.11, as 0.11 creates these by default
-if vim.fn.has("nvim-0.11") == 0 then
- map("s", "", function()
- return vim.snippet.active({ direction = 1 }) and "lua vim.snippet.jump(1)" or ""
- end, { expr = true, desc = "Jump Next" })
- map({ "i", "s" }, "", function()
- return vim.snippet.active({ direction = -1 }) and "lua vim.snippet.jump(-1)" or ""
- end, { expr = true, desc = "Jump Previous" })
-end
diff --git a/lua/lazyvim/config/options.lua b/lua/lazyvim/config/options.lua
index 0bbaacba..b5d444d0 100644
--- a/lua/lazyvim/config/options.lua
+++ b/lua/lazyvim/config/options.lua
@@ -68,7 +68,10 @@ opt.fillchars = {
diff = "╱",
eob = " ",
}
+opt.foldexpr = "v:lua.require'lazyvim.util'.ui.foldexpr()"
opt.foldlevel = 99
+opt.foldmethod = "expr"
+opt.foldtext = ""
opt.formatexpr = "v:lua.require'lazyvim.util'.format.formatexpr()"
opt.formatoptions = "jcroqlnt" -- tcqj
opt.grepformat = "%f:%l:%c:%m"
@@ -95,6 +98,7 @@ opt.sidescrolloff = 8 -- Columns of context
opt.signcolumn = "yes" -- Always show the signcolumn, otherwise it would shift the text each time
opt.smartcase = true -- Don't ignore case with capitals
opt.smartindent = true -- Insert indents automatically
+opt.smoothscroll = true
opt.spelllang = { "en" }
opt.splitbelow = true -- Put new windows below current
opt.splitkeep = "screen"
@@ -111,15 +115,5 @@ opt.wildmode = "longest:full,full" -- Command-line completion mode
opt.winminwidth = 5 -- Minimum window width
opt.wrap = false -- Disable line wrap
-if vim.fn.has("nvim-0.10") == 1 then
- opt.smoothscroll = true
- opt.foldexpr = "v:lua.require'lazyvim.util'.ui.foldexpr()"
- opt.foldmethod = "expr"
- opt.foldtext = ""
-else
- opt.foldmethod = "indent"
- opt.foldtext = "v:lua.require'lazyvim.util'.ui.foldtext()"
-end
-
-- Fix markdown indentation settings
vim.g.markdown_recommended_style = 0
diff --git a/lua/lazyvim/health.lua b/lua/lazyvim/health.lua
index 9fdc5a56..716c60a8 100644
--- a/lua/lazyvim/health.lua
+++ b/lua/lazyvim/health.lua
@@ -8,13 +8,10 @@ local error = vim.health.error or vim.health.report_error
function M.check()
start("LazyVim")
- if vim.fn.has("nvim-0.9.0") == 1 then
- ok("Using Neovim >= 0.9.0")
- if vim.fn.has("nvim-0.10.0") == 0 then
- warn("Use Neovim >= 0.10.0 for the best experience")
- end
+ if vim.fn.has("nvim-0.11.0") == 1 then
+ ok("Using Neovim >= 0.11.0")
else
- error("Neovim >= 0.9.0 is required")
+ error("Neovim >= 0.11.0 is required")
end
for _, cmd in ipairs({ "git", "rg", { "fd", "fdfind" }, "lazygit", "fzf", "curl" }) do
diff --git a/lua/lazyvim/plugins/coding.lua b/lua/lazyvim/plugins/coding.lua
index 0e614e48..8b242eb8 100644
--- a/lua/lazyvim/plugins/coding.lua
+++ b/lua/lazyvim/plugins/coding.lua
@@ -1,7 +1,7 @@
return {
-- auto pairs
{
- "echasnovski/mini.pairs",
+ "nvim-mini/mini.pairs",
event = "VeryLazy",
opts = {
modes = { insert = true, command = true, terminal = false },
@@ -29,7 +29,7 @@ return {
-- Better text-objects
{
- "echasnovski/mini.ai",
+ "nvim-mini/mini.ai",
event = "VeryLazy",
opts = function()
local ai = require("mini.ai")
diff --git a/lua/lazyvim/plugins/colorscheme.lua b/lua/lazyvim/plugins/colorscheme.lua
index fa611bf4..4c41d492 100644
--- a/lua/lazyvim/plugins/colorscheme.lua
+++ b/lua/lazyvim/plugins/colorscheme.lua
@@ -58,7 +58,7 @@ return {
optional = true,
opts = function(_, opts)
if (vim.g.colors_name or ""):find("catppuccin") then
- opts.highlights = require("catppuccin.groups.integrations.bufferline").get()
+ opts.highlights = require("catppuccin.groups.integrations.bufferline").get_theme()
end
end,
},
diff --git a/lua/lazyvim/plugins/compat/nvim-0_9.lua b/lua/lazyvim/plugins/compat/nvim-0_9.lua
deleted file mode 100644
index 81514ef8..00000000
--- a/lua/lazyvim/plugins/compat/nvim-0_9.lua
+++ /dev/null
@@ -1,41 +0,0 @@
--- Compatibility with Neovim 0.9
-return {
- -- Use LuaSnip instead of native snippets
- { "garymjr/nvim-snippets", enabled = false },
- { import = "lazyvim.plugins.extras.coding.luasnip" },
-
- -- Use nvim-cmp instead of blink.cmp
- { import = "lazyvim.plugins.extras.coding.nvim-cmp" },
-
- -- Use mini.comment instead of ts-comments
- { "folke/ts-comments.nvim", enabled = false },
- { import = "lazyvim.plugins.extras.coding.mini-comment" },
-
- -- Use neodev-types with lazydev
- { "folke/neodev.nvim", config = function() end },
- {
- "folke/lazydev.nvim",
- opts = function(_, opts)
- opts.library = opts.library or {}
- table.insert(opts.library, { "neodev.nvim/types/stable" })
- end,
- config = function(_, opts)
- -- force lazydev to load on Neovim 0.9
- require("lazydev.config").have_0_10 = true
- require("lazydev").setup(opts)
- end,
- },
- {
- "neovim/nvim-lspconfig",
- dependencies = {},
- },
-
- -- dummy import to save core imports
- {
- import = "foobar",
- enabled = function()
- LazyVim.plugin.save_core()
- return false
- end,
- },
-}
diff --git a/lua/lazyvim/plugins/extras/ai/copilot-chat.lua b/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
index 58169b1e..fbf4ee39 100644
--- a/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
+++ b/lua/lazyvim/plugins/extras/ai/copilot-chat.lua
@@ -85,4 +85,24 @@ return {
})
end,
},
+
+ -- Blink integration
+ {
+ "saghen/blink.cmp",
+ optional = true,
+ ---@module 'blink.cmp'
+ ---@type blink.cmp.Config
+ opts = {
+ sources = {
+ providers = {
+ path = {
+ -- Path sources triggered by "/" interfere with CopilotChat commands
+ enabled = function()
+ return vim.bo.filetype ~= "copilot-chat"
+ end,
+ },
+ },
+ },
+ },
+ },
}
diff --git a/lua/lazyvim/plugins/extras/ai/copilot.lua b/lua/lazyvim/plugins/extras/ai/copilot.lua
index 4f1d54f2..deebcd7d 100644
--- a/lua/lazyvim/plugins/extras/ai/copilot.lua
+++ b/lua/lazyvim/plugins/extras/ai/copilot.lua
@@ -51,7 +51,7 @@ return {
LazyVim.lualine.status(LazyVim.config.icons.kinds.Copilot, function()
local clients = package.loaded["copilot"] and LazyVim.lsp.get_clients({ name = "copilot", bufnr = 0 }) or {}
if #clients > 0 then
- local status = require("copilot.api").status.data.status
+ local status = require("copilot.status").data.status
return (status == "InProgress" and "pending") or (status == "Warning" and "error") or "ok"
end
end)
diff --git a/lua/lazyvim/plugins/extras/coding/blink.lua b/lua/lazyvim/plugins/extras/coding/blink.lua
index 10b2ee62..fe45b86b 100644
--- a/lua/lazyvim/plugins/extras/coding/blink.lua
+++ b/lua/lazyvim/plugins/extras/coding/blink.lua
@@ -109,7 +109,7 @@ return {
if not opts.keymap[""] then
if opts.keymap.preset == "super-tab" then -- super-tab
opts.keymap[""] = {
- require("blink.cmp.keymap.presets")["super-tab"][""][1],
+ require("blink.cmp.keymap.presets").get("super-tab")[""][1],
LazyVim.cmp.map({ "snippet_forward", "ai_accept" }),
"fallback",
}
diff --git a/lua/lazyvim/plugins/extras/coding/mini-comment.lua b/lua/lazyvim/plugins/extras/coding/mini-comment.lua
index 457787ef..19113d67 100644
--- a/lua/lazyvim/plugins/extras/coding/mini-comment.lua
+++ b/lua/lazyvim/plugins/extras/coding/mini-comment.lua
@@ -1,6 +1,6 @@
return {
{
- "echasnovski/mini.comment",
+ "nvim-mini/mini.comment",
event = "VeryLazy",
opts = {
options = {
diff --git a/lua/lazyvim/plugins/extras/coding/mini-snippets.lua b/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
index d0a747a8..714d867d 100644
--- a/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
+++ b/lua/lazyvim/plugins/extras/coding/mini-snippets.lua
@@ -4,14 +4,14 @@ if lazyvim_docs then
vim.g.lazyvim_mini_snippets_in_completion = true
-- NOTE: Please also read:
- -- https://github.com/echasnovski/mini.nvim/blob/main/readmes/mini-snippets.md#expand
+ -- https://github.com/nvim-mini/mini.nvim/blob/main/readmes/mini-snippets.md#expand
-- :h MiniSnippets-session
-- Example override for your own config:
--[[
return {
{
- "echasnovski/mini.snippets",
+ "nvim-mini/mini.snippets",
opts = function(_, opts)
-- By default, for opts.snippets, the extra for mini.snippets only adds gen_loader.from_lang()
-- This provides a sensible quickstart, integrating with friendly-snippets
@@ -63,7 +63,7 @@ return {
-- add mini.snippets
desc = "Manage and expand snippets (alternative to Luasnip)",
{
- "echasnovski/mini.snippets",
+ "nvim-mini/mini.snippets",
event = "InsertEnter", -- don't depend on other plugins to load...
dependencies = "rafamadriz/friendly-snippets",
opts = function()
diff --git a/lua/lazyvim/plugins/extras/coding/mini-surround.lua b/lua/lazyvim/plugins/extras/coding/mini-surround.lua
index d8ff25c5..19c5de8f 100644
--- a/lua/lazyvim/plugins/extras/coding/mini-surround.lua
+++ b/lua/lazyvim/plugins/extras/coding/mini-surround.lua
@@ -3,7 +3,7 @@
-- to select the text inside, change or modify the surrounding characters,
-- and more.
return {
- "echasnovski/mini.surround",
+ "nvim-mini/mini.surround",
keys = function(_, keys)
-- Populate the keys based on the user's options
local opts = LazyVim.opts("mini.surround")
diff --git a/lua/lazyvim/plugins/extras/editor/harpoon2.lua b/lua/lazyvim/plugins/extras/editor/harpoon2.lua
index 760d805a..699c2546 100644
--- a/lua/lazyvim/plugins/extras/editor/harpoon2.lua
+++ b/lua/lazyvim/plugins/extras/editor/harpoon2.lua
@@ -28,7 +28,7 @@ return {
},
}
- for i = 1, 5 do
+ for i = 1, 9 do
table.insert(keys, {
"" .. i,
function()
diff --git a/lua/lazyvim/plugins/extras/editor/leap.lua b/lua/lazyvim/plugins/extras/editor/leap.lua
index 19c8b331..3fe4c5e7 100644
--- a/lua/lazyvim/plugins/extras/editor/leap.lua
+++ b/lua/lazyvim/plugins/extras/editor/leap.lua
@@ -37,7 +37,7 @@ return {
-- rename surround mappings from gs to gz to prevent conflict with leap
{
- "echasnovski/mini.surround",
+ "nvim-mini/mini.surround",
optional = true,
opts = {
mappings = {
diff --git a/lua/lazyvim/plugins/extras/editor/mini-diff.lua b/lua/lazyvim/plugins/extras/editor/mini-diff.lua
index fe25c11e..ea2e216d 100644
--- a/lua/lazyvim/plugins/extras/editor/mini-diff.lua
+++ b/lua/lazyvim/plugins/extras/editor/mini-diff.lua
@@ -7,7 +7,7 @@ return {
-- setup mini.diff
{
- "echasnovski/mini.diff",
+ "nvim-mini/mini.diff",
event = "VeryLazy",
keys = {
{
diff --git a/lua/lazyvim/plugins/extras/editor/mini-files.lua b/lua/lazyvim/plugins/extras/editor/mini-files.lua
index 70a42940..30cc14fc 100644
--- a/lua/lazyvim/plugins/extras/editor/mini-files.lua
+++ b/lua/lazyvim/plugins/extras/editor/mini-files.lua
@@ -1,5 +1,5 @@
return {
- "echasnovski/mini.files",
+ "nvim-mini/mini.files",
opts = {
windows = {
preview = true,
diff --git a/lua/lazyvim/plugins/extras/editor/mini-move.lua b/lua/lazyvim/plugins/extras/editor/mini-move.lua
index aa8823ef..26e977fd 100644
--- a/lua/lazyvim/plugins/extras/editor/mini-move.lua
+++ b/lua/lazyvim/plugins/extras/editor/mini-move.lua
@@ -1,6 +1,6 @@
return {
{
- "echasnovski/mini.move",
+ "nvim-mini/mini.move",
event = "VeryLazy",
opts = {},
},
diff --git a/lua/lazyvim/plugins/extras/editor/navic.lua b/lua/lazyvim/plugins/extras/editor/navic.lua
index e25d1b51..91ec203c 100644
--- a/lua/lazyvim/plugins/extras/editor/navic.lua
+++ b/lua/lazyvim/plugins/extras/editor/navic.lua
@@ -8,7 +8,7 @@ return {
init = function()
vim.g.navic_silence = true
LazyVim.lsp.on_attach(function(client, buffer)
- if client.supports_method("textDocument/documentSymbol") then
+ if client:supports_method("textDocument/documentSymbol") then
require("nvim-navic").attach(client, buffer)
end
end)
diff --git a/lua/lazyvim/plugins/extras/editor/snacks_picker.lua b/lua/lazyvim/plugins/extras/editor/snacks_picker.lua
index 93f32fab..591da5ea 100644
--- a/lua/lazyvim/plugins/extras/editor/snacks_picker.lua
+++ b/lua/lazyvim/plugins/extras/editor/snacks_picker.lua
@@ -178,7 +178,7 @@ return {
end,
},
{
- "echasnovski/mini.starter",
+ "nvim-mini/mini.starter",
optional = true,
opts = function(_, opts)
local items = {
diff --git a/lua/lazyvim/plugins/extras/lang/go.lua b/lua/lazyvim/plugins/extras/lang/go.lua
index ff8def2e..77536fea 100644
--- a/lua/lazyvim/plugins/extras/lang/go.lua
+++ b/lua/lazyvim/plugins/extras/lang/go.lua
@@ -139,7 +139,7 @@ return {
-- Filetype icons
{
- "echasnovski/mini.icons",
+ "nvim-mini/mini.icons",
opts = {
file = {
[".go-version"] = { glyph = "", hl = "MiniIconsBlue" },
diff --git a/lua/lazyvim/plugins/extras/lang/python.lua b/lua/lazyvim/plugins/extras/lang/python.lua
index 4c098452..3298f6dd 100644
--- a/lua/lazyvim/plugins/extras/lang/python.lua
+++ b/lua/lazyvim/plugins/extras/lang/python.lua
@@ -114,11 +114,7 @@ return {
{
"linux-cultist/venv-selector.nvim",
- branch = "regexp", -- Use this branch for the new version
cmd = "VenvSelect",
- enabled = function()
- return LazyVim.has("telescope.nvim")
- end,
opts = {
settings = {
options = {
@@ -126,7 +122,7 @@ return {
},
},
},
- -- Call config for python files and load the cached venv automatically
+ -- Call config for Python files and load the cached venv automatically
ft = "python",
keys = { { "cv", ":VenvSelect", desc = "Select VirtualEnv", ft = "python" } },
},
diff --git a/lua/lazyvim/plugins/extras/lang/ruby.lua b/lua/lazyvim/plugins/extras/lang/ruby.lua
index 4224e6d8..65620f4e 100644
--- a/lua/lazyvim/plugins/extras/lang/ruby.lua
+++ b/lua/lazyvim/plugins/extras/lang/ruby.lua
@@ -6,10 +6,6 @@ if lazyvim_docs then
end
local lsp = vim.g.lazyvim_ruby_lsp or "ruby_lsp"
-if vim.fn.has("nvim-0.10") == 0 then
- -- ruby_lsp does not work well with Neovim < 0.10
- lsp = vim.g.lazyvim_ruby_lsp or "solargraph"
-end
local formatter = vim.g.lazyvim_ruby_formatter or "rubocop"
return {
diff --git a/lua/lazyvim/plugins/extras/lang/rust.lua b/lua/lazyvim/plugins/extras/lang/rust.lua
index b5da242e..b66dde9b 100644
--- a/lua/lazyvim/plugins/extras/lang/rust.lua
+++ b/lua/lazyvim/plugins/extras/lang/rust.lua
@@ -56,7 +56,6 @@ return {
{
"mrcjkb/rustaceanvim",
- version = vim.fn.has("nvim-0.10.0") == 0 and "^4" or false,
ft = { "rust" },
opts = {
server = {
diff --git a/lua/lazyvim/plugins/extras/lang/svelte.lua b/lua/lazyvim/plugins/extras/lang/svelte.lua
index 565e50e5..4060e2f3 100644
--- a/lua/lazyvim/plugins/extras/lang/svelte.lua
+++ b/lua/lazyvim/plugins/extras/lang/svelte.lua
@@ -31,11 +31,6 @@ return {
desc = "Organize Imports",
},
},
- capabilities = {
- workspace = {
- didChangeWatchedFiles = vim.fn.has("nvim-0.10") == 0 and { dynamicRegistration = true },
- },
- },
},
},
},
diff --git a/lua/lazyvim/plugins/extras/lang/typescript.lua b/lua/lazyvim/plugins/extras/lang/typescript.lua
index f7cc3231..3830f795 100644
--- a/lua/lazyvim/plugins/extras/lang/typescript.lua
+++ b/lua/lazyvim/plugins/extras/lang/typescript.lua
@@ -137,14 +137,14 @@ return {
local action, uri, range = unpack(command.arguments)
local function move(newf)
- client.request("workspace/executeCommand", {
+ client:request("workspace/executeCommand", {
command = command.command,
arguments = { action, uri, range, newf },
})
end
local fname = vim.uri_to_fname(uri)
- client.request("workspace/executeCommand", {
+ client:request("workspace/executeCommand", {
command = "typescript.tsserverRequest",
arguments = {
"getMoveToRefactoringFileSuggestions",
@@ -263,7 +263,7 @@ return {
-- Filetype icons
{
- "echasnovski/mini.icons",
+ "nvim-mini/mini.icons",
opts = {
file = {
[".eslintrc.js"] = { glyph = "", hl = "MiniIconsYellow" },
diff --git a/lua/lazyvim/plugins/extras/lang/yaml.lua b/lua/lazyvim/plugins/extras/lang/yaml.lua
index 9a3aadb8..b460f3c5 100644
--- a/lua/lazyvim/plugins/extras/lang/yaml.lua
+++ b/lua/lazyvim/plugins/extras/lang/yaml.lua
@@ -55,16 +55,6 @@ return {
},
},
},
- setup = {
- yamlls = function()
- -- Neovim < 0.10 does not have dynamic registration for formatting
- if vim.fn.has("nvim-0.10") == 0 then
- LazyVim.lsp.on_attach(function(client, _)
- client.server_capabilities.documentFormattingProvider = true
- end, "yamlls")
- end
- end,
- },
},
},
}
diff --git a/lua/lazyvim/plugins/extras/ui/mini-animate.lua b/lua/lazyvim/plugins/extras/ui/mini-animate.lua
index bbd3e587..5a3fdef6 100644
--- a/lua/lazyvim/plugins/extras/ui/mini-animate.lua
+++ b/lua/lazyvim/plugins/extras/ui/mini-animate.lua
@@ -10,7 +10,7 @@ return {
-- setup animate
{
- "echasnovski/mini.animate",
+ "nvim-mini/mini.animate",
event = "VeryLazy",
cond = vim.g.neovide == nil,
opts = function(_, opts)
diff --git a/lua/lazyvim/plugins/extras/ui/mini-indentscope.lua b/lua/lazyvim/plugins/extras/ui/mini-indentscope.lua
index 91ec1d45..ea266b24 100644
--- a/lua/lazyvim/plugins/extras/ui/mini-indentscope.lua
+++ b/lua/lazyvim/plugins/extras/ui/mini-indentscope.lua
@@ -3,7 +3,7 @@ return {
-- code, this highlights the current level of indentation, and animates
-- the highlighting.
{
- "echasnovski/mini.indentscope",
+ "nvim-mini/mini.indentscope",
version = false, -- wait till new 0.7.0 release to put it back on semver
event = "LazyFile",
opts = {
diff --git a/lua/lazyvim/plugins/extras/ui/smear-cursor.lua b/lua/lazyvim/plugins/extras/ui/smear-cursor.lua
index 070d2623..2ca27780 100644
--- a/lua/lazyvim/plugins/extras/ui/smear-cursor.lua
+++ b/lua/lazyvim/plugins/extras/ui/smear-cursor.lua
@@ -9,7 +9,7 @@ return {
specs = {
-- disable mini.animate cursor
{
- "echasnovski/mini.animate",
+ "nvim-mini/mini.animate",
optional = true,
opts = {
cursor = { enable = false },
diff --git a/lua/lazyvim/plugins/extras/util/chezmoi.lua b/lua/lazyvim/plugins/extras/util/chezmoi.lua
index 6c88fc45..2c1b2f31 100644
--- a/lua/lazyvim/plugins/extras/util/chezmoi.lua
+++ b/lua/lazyvim/plugins/extras/util/chezmoi.lua
@@ -135,7 +135,7 @@ return {
-- Filetype icons
{
- "echasnovski/mini.icons",
+ "nvim-mini/mini.icons",
opts = {
file = {
[".chezmoiignore"] = { glyph = "", hl = "MiniIconsGrey" },
diff --git a/lua/lazyvim/plugins/extras/util/mini-hipatterns.lua b/lua/lazyvim/plugins/extras/util/mini-hipatterns.lua
index 287c0d77..b8fa4d1a 100644
--- a/lua/lazyvim/plugins/extras/util/mini-hipatterns.lua
+++ b/lua/lazyvim/plugins/extras/util/mini-hipatterns.lua
@@ -4,7 +4,7 @@ local M = {}
M.hl = {}
M.plugin = {
- "echasnovski/mini.hipatterns",
+ "nvim-mini/mini.hipatterns",
recommended = true,
desc = "Highlight colors in your code. Also includes Tailwind CSS support.",
event = "LazyFile",
diff --git a/lua/lazyvim/plugins/extras/util/project.lua b/lua/lazyvim/plugins/extras/util/project.lua
index 01a25bc2..dafaa594 100644
--- a/lua/lazyvim/plugins/extras/util/project.lua
+++ b/lua/lazyvim/plugins/extras/util/project.lua
@@ -134,7 +134,7 @@ return {
},
{
- "echasnovski/mini.starter",
+ "nvim-mini/mini.starter",
optional = true,
opts = function(_, opts)
local items = {
diff --git a/lua/lazyvim/plugins/init.lua b/lua/lazyvim/plugins/init.lua
index c06fa9bc..a0faebcd 100644
--- a/lua/lazyvim/plugins/init.lua
+++ b/lua/lazyvim/plugins/init.lua
@@ -1,6 +1,7 @@
-if vim.fn.has("nvim-0.9.0") == 0 then
+if vim.fn.has("nvim-0.11.0") == 0 then
vim.api.nvim_echo({
- { "LazyVim requires Neovim >= 0.9.0\n", "ErrorMsg" },
+ { "LazyVim requires Neovim >= 0.11.0\n", "ErrorMsg" },
+ { "For more info, see: https://github.com/LazyVim/LazyVim/issues/6421\n", "Comment" },
{ "Press any key to exit", "MoreMsg" },
}, true, {})
vim.fn.getchar()
diff --git a/lua/lazyvim/plugins/lsp/init.lua b/lua/lazyvim/plugins/lsp/init.lua
index 15f41e91..dbdbea47 100644
--- a/lua/lazyvim/plugins/lsp/init.lua
+++ b/lua/lazyvim/plugins/lsp/init.lua
@@ -129,53 +129,39 @@ return {
LazyVim.lsp.setup()
LazyVim.lsp.on_dynamic_capability(require("lazyvim.plugins.lsp.keymaps").on_attach)
- -- diagnostics signs
- if vim.fn.has("nvim-0.10.0") == 0 then
- if type(opts.diagnostics.signs) ~= "boolean" then
- for severity, icon in pairs(opts.diagnostics.signs.text) do
- local name = vim.diagnostic.severity[severity]:lower():gsub("^%l", string.upper)
- name = "DiagnosticSign" .. name
- vim.fn.sign_define(name, { text = icon, texthl = name, numhl = "" })
+ -- inlay hints
+ if opts.inlay_hints.enabled then
+ LazyVim.lsp.on_supports_method("textDocument/inlayHint", function(client, buffer)
+ if
+ vim.api.nvim_buf_is_valid(buffer)
+ and vim.bo[buffer].buftype == ""
+ and not vim.tbl_contains(opts.inlay_hints.exclude, vim.bo[buffer].filetype)
+ then
+ vim.lsp.inlay_hint.enable(true, { bufnr = buffer })
end
- end
+ end)
end
- if vim.fn.has("nvim-0.10") == 1 then
- -- inlay hints
- if opts.inlay_hints.enabled then
- LazyVim.lsp.on_supports_method("textDocument/inlayHint", function(client, buffer)
- if
- vim.api.nvim_buf_is_valid(buffer)
- and vim.bo[buffer].buftype == ""
- and not vim.tbl_contains(opts.inlay_hints.exclude, vim.bo[buffer].filetype)
- then
- vim.lsp.inlay_hint.enable(true, { bufnr = buffer })
- end
- end)
- end
-
- -- code lens
- if opts.codelens.enabled and vim.lsp.codelens then
- LazyVim.lsp.on_supports_method("textDocument/codeLens", function(client, buffer)
- vim.lsp.codelens.refresh()
- vim.api.nvim_create_autocmd({ "BufEnter", "CursorHold", "InsertLeave" }, {
- buffer = buffer,
- callback = vim.lsp.codelens.refresh,
- })
- end)
- end
+ -- code lens
+ if opts.codelens.enabled and vim.lsp.codelens then
+ LazyVim.lsp.on_supports_method("textDocument/codeLens", function(client, buffer)
+ vim.lsp.codelens.refresh()
+ vim.api.nvim_create_autocmd({ "BufEnter", "CursorHold", "InsertLeave" }, {
+ buffer = buffer,
+ callback = vim.lsp.codelens.refresh,
+ })
+ end)
end
if type(opts.diagnostics.virtual_text) == "table" and opts.diagnostics.virtual_text.prefix == "icons" then
- opts.diagnostics.virtual_text.prefix = vim.fn.has("nvim-0.10.0") == 0 and "●"
- or function(diagnostic)
- local icons = LazyVim.config.icons.diagnostics
- for d, icon in pairs(icons) do
- if diagnostic.severity == vim.diagnostic.severity[d:upper()] then
- return icon
- end
+ opts.diagnostics.virtual_text.prefix = function(diagnostic)
+ local icons = LazyVim.config.icons.diagnostics
+ for d, icon in pairs(icons) do
+ if diagnostic.severity == vim.diagnostic.severity[d:upper()] then
+ return icon
end
end
+ end
end
vim.diagnostic.config(vim.deepcopy(opts.diagnostics))
diff --git a/lua/lazyvim/plugins/lsp/keymaps.lua b/lua/lazyvim/plugins/lsp/keymaps.lua
index 318ec911..748f5b29 100644
--- a/lua/lazyvim/plugins/lsp/keymaps.lua
+++ b/lua/lazyvim/plugins/lsp/keymaps.lua
@@ -54,7 +54,7 @@ function M.has(buffer, method)
method = method:find("/") and method or "textDocument/" .. method
local clients = LazyVim.lsp.get_clients({ bufnr = buffer })
for _, client in ipairs(clients) do
- if client.supports_method(method) then
+ if client:supports_method(method) then
return true
end
end
diff --git a/lua/lazyvim/plugins/ui.lua b/lua/lazyvim/plugins/ui.lua
index 7985825a..9dd7254b 100644
--- a/lua/lazyvim/plugins/ui.lua
+++ b/lua/lazyvim/plugins/ui.lua
@@ -245,7 +245,7 @@ return {
-- icons
{
- "echasnovski/mini.icons",
+ "nvim-mini/mini.icons",
lazy = true,
opts = {
file = {
diff --git a/lua/lazyvim/plugins/xtras.lua b/lua/lazyvim/plugins/xtras.lua
index bb061d80..19a5c6da 100644
--- a/lua/lazyvim/plugins/xtras.lua
+++ b/lua/lazyvim/plugins/xtras.lua
@@ -3,7 +3,8 @@ local prios = {
["lazyvim.plugins.extras.test.core"] = 1,
["lazyvim.plugins.extras.dap.core"] = 1,
["lazyvim.plugins.extras.coding.nvim-cmp"] = 2,
- ["lazyvim.plugins.extras.ui.edgy"] = 2,
+ ["lazyvim.plugins.extras.editor.neo-tree"] = 2,
+ ["lazyvim.plugins.extras.ui.edgy"] = 3,
["lazyvim.plugins.extras.lang.typescript"] = 5,
["lazyvim.plugins.extras.coding.blink"] = 5,
["lazyvim.plugins.extras.formatting.prettier"] = 10,
@@ -42,15 +43,7 @@ end
---@type string[]
extras = LazyVim.dedup(extras)
-local version = vim.version()
-local v = version.major .. "_" .. version.minor
-
-local compat = { "0_9" }
-
LazyVim.plugin.save_core()
-if vim.tbl_contains(compat, v) then
- table.insert(extras, 1, "lazyvim.plugins.compat.nvim-" .. v)
-end
if vim.g.vscode then
table.insert(extras, 1, "lazyvim.plugins.extras.vscode")
end
diff --git a/lua/lazyvim/util/lsp.lua b/lua/lazyvim/util/lsp.lua
index e868dcf0..02ab8b6e 100644
--- a/lua/lazyvim/util/lsp.lua
+++ b/lua/lazyvim/util/lsp.lua
@@ -1,23 +1,12 @@
---@class lazyvim.util.lsp
local M = {}
----@alias lsp.Client.filter {id?: number, bufnr?: number, name?: string, method?: string, filter?:fun(client: lsp.Client):boolean}
+---@alias lsp.Client.filter {id?: number, bufnr?: number, name?: string, method?: string, filter?:fun(client: vim.lsp.Client):boolean}
---@param opts? lsp.Client.filter
function M.get_clients(opts)
local ret = {} ---@type vim.lsp.Client[]
- if vim.lsp.get_clients then
- ret = vim.lsp.get_clients(opts)
- else
- ---@diagnostic disable-next-line: deprecated
- ret = vim.lsp.get_active_clients(opts)
- if opts and opts.method then
- ---@param client vim.lsp.Client
- ret = vim.tbl_filter(function(client)
- return client.supports_method(opts.method, { bufnr = opts.bufnr })
- end, ret)
- end
- end
+ ret = vim.lsp.get_clients(opts)
return opts and opts.filter and vim.tbl_filter(opts.filter, ret) or ret
end
@@ -75,7 +64,7 @@ function M._check_methods(client, buffer)
for method, clients in pairs(M._supports_method) do
clients[client] = clients[client] or {}
if not clients[client][buffer] then
- if client.supports_method and client.supports_method(method, { bufnr = buffer }) then
+ if client.supports_method and client:supports_method(method, { bufnr = buffer }) then
clients[client][buffer] = true
vim.api.nvim_exec_autocmds("User", {
pattern = "LspSupportsMethod",
@@ -169,8 +158,8 @@ function M.formatter(opts)
local clients = M.get_clients(LazyVim.merge({}, filter, { bufnr = buf }))
---@param client vim.lsp.Client
local ret = vim.tbl_filter(function(client)
- return client.supports_method("textDocument/formatting")
- or client.supports_method("textDocument/rangeFormatting")
+ return client:supports_method("textDocument/formatting")
+ or client:supports_method("textDocument/rangeFormatting")
end, clients)
---@param client vim.lsp.Client
return vim.tbl_map(function(client)
diff --git a/lua/lazyvim/util/plugin.lua b/lua/lazyvim/util/plugin.lua
index 9fede549..ff3f3634 100644
--- a/lua/lazyvim/util/plugin.lua
+++ b/lua/lazyvim/util/plugin.lua
@@ -1,3 +1,4 @@
+local Meta = require("lazy.core.meta")
local Plugin = require("lazy.core.plugin")
---@class lazyvim.util.plugin
@@ -102,9 +103,17 @@ function M.fix_imports()
end
function M.fix_renames()
- Plugin.Spec.add = LazyVim.inject.args(Plugin.Spec.add, function(self, plugin)
+ ---@param plugin LazyPluginSpec
+ Meta.add = LazyVim.inject.args(Meta.add, function(self, plugin)
if type(plugin) == "table" then
- if M.renames[plugin[1]] then
+ local name = plugin[1]
+ if not name then
+ return
+ end
+ if name:find("echasnovski") then
+ M.renames[name] = name:gsub("echasnovski", "nvim-mini")
+ end
+ if M.renames[name] then
LazyVim.warn(
("Plugin `%s` was renamed to `%s`.\nPlease update your config for `%s`"):format(
plugin[1],
@@ -113,7 +122,7 @@ function M.fix_renames()
),
{ title = "LazyVim" }
)
- plugin[1] = M.renames[plugin[1]]
+ plugin[1] = M.renames[name]
end
end
end)
diff --git a/lua/lazyvim/util/ui.lua b/lua/lazyvim/util/ui.lua
index 3460b0ab..c8c899d5 100644
--- a/lua/lazyvim/util/ui.lua
+++ b/lua/lazyvim/util/ui.lua
@@ -1,11 +1,6 @@
---@class lazyvim.util.ui
local M = {}
--- foldtext for Neovim < 0.10.0
-function M.foldtext()
- return vim.api.nvim_buf_get_lines(0, vim.v.lnum - 1, vim.v.lnum, false)[1]
-end
-
-- optimized treesitter foldexpr for Neovim >= 0.10.0
function M.foldexpr()
local buf = vim.api.nvim_get_current_buf()
diff --git a/tests/minit.lua b/tests/minit.lua
index 3eb3a8b4..c7240d96 100644
--- a/tests/minit.lua
+++ b/tests/minit.lua
@@ -7,10 +7,10 @@ load(vim.fn.system("curl -s https://raw.githubusercontent.com/folke/lazy.nvim/ma
require("lazy.minit").setup({
spec = {
{ dir = vim.uv.cwd() },
- "LazyVim/starter",
- "mason-org/mason-lspconfig.nvim",
- "mason-org/mason.nvim",
- "nvim-treesitter/nvim-treesitter",
- { "echasnovski/mini.icons", opts = {} },
+ { "LazyVim/starter" },
+ { "nvim-treesitter/nvim-treesitter" },
+ { "mason-org/mason-lspconfig.nvim", version = "^1.0.0" },
+ { "mason-org/mason.nvim", version = "^1.0.0" },
+ { "nvim-mini/mini.icons", opts = {} },
},
})
diff --git a/lua/lazyvim/plugins/extras/ui/mini-starter.lua b/lua/lazyvim/plugins/extras/ui/mini-starter.lua
index c1bd7bc1..51444df5 100644
--- a/lua/lazyvim/plugins/extras/ui/mini-starter.lua
+++ b/lua/lazyvim/plugins/extras/ui/mini-starter.lua
@@ -5,7 +5,7 @@ return {
-- enable mini.starter
{
- "echasnovski/mini.starter",
+ "nvim-mini/mini.starter",
version = false, -- wait till new 0.7.0 release to put it back on semver
event = "VimEnter",
opts = function()
@@ -67,7 +67,7 @@ return {
local ms = (math.floor(stats.startuptime * 100 + 0.5) / 100)
local pad_footer = string.rep(" ", 8)
starter.config.footer = pad_footer .. "⚡ Neovim loaded " .. stats.count .. " plugins in " .. ms .. "ms"
- -- INFO: based on @echasnovski's recommendation (thanks a lot!!!)
+ -- INFO: based on @nvim-mini's recommendation (thanks a lot!!!)
if vim.bo[ev.buf].filetype == "ministarter" then
pcall(starter.refresh)
end